<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\OptionGroup;
use App\Models\Option;
use Validator;
use Exception;
use DB;

class OptionGroupController extends Controller
{
	protected $model;
	protected $basicViewPath = 'admin.option_groups.';

    public function __construct()
    {
    	$this->model = new OptionGroup();

    	$this->middleware('auth:admin');

    }

    public function index(){
    	$resources = $this->model->paginate(10);
    	// return $resources;
    	return view($this->basicViewPath.'index')->with(['resources'=>$resources]);
    }

    public function create(){
    	$resource = $this->model;
    	return view($this->basicViewPath.'create')->with(['resource'=>$resource]);	
    }

    public function store(Request $request){
    	$rules = [
            'name' => 'required',
            'options' => 'array'
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            return response()->json(array('errors' => $validator->getMessageBag()->toArray()));
        }

    	DB::beginTransaction();

    	try {

    		$resource = $this->model;
	    	$resource->name = $request->name;
	    	$resource->save();
	    	if ($request->has('options') && !empty($request->options)) {
		    	foreach ($request->options as $option) {
		    		Option::create([
		    			'name'=>$option,
		    			'option_group_id'=>$resource->id
		    		]);
		    	}
	    	}

	    	DB::commit();

	    	$msg = 'New Group Added Successfully.<a href="' . route('admin.option_groups.index') . '">View Groups Lists.</a>';
        	return response()->json($msg);
    	} catch (Exception $e) {
    		DB::rollBack();
    		return response()->json(array('errors' => [$e->getMessage()]));
    	}
    	
    }


    public function edit($id){
    	$resource = $this->model->where('id',$id)->first();
    	return view($this->basicViewPath.'edit')->with(['resource'=>$resource]);
    }


    public function update($id,Request $request){

    	// return $request->old_options;

    	$rules = [
            'name' => 'required',
            'options' => 'array'
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            return response()->json(array('errors' => $validator->getMessageBag()->toArray()));
        }

    	DB::beginTransaction();

    	try {

    		$resource = $this->model->where('id',$id)->first();
	    	$resource->update(['name'=>$request->name]);
	    	$unDeletedOldOptions = [];

	    	if ($request->has('old_options') && !empty($request->old_options)) {
	    	
	    		foreach ($request->old_options as $key => $oldOption) {
	    			array_push($unDeletedOldOptions, $oldOption['option']);
	    			
	    			$oldOptionSaved = Option::where('id',$oldOption['id'])->first();

	    			if (!empty($oldOption['option'])) {
	    				
	    				if ($oldOptionSaved) {

	    					$oldOptionSaved->update(['name'=>$oldOption['option']]);

	    				}

	    			}
	    		}
	    	
	    	}

	    	// return $unDeletedOldOptions;

	    	Option::where('option_group_id',$id)->whereNotIn('id',$unDeletedOldOptions)->delete();

	    	if ($request->has('options') && !empty($request->options)) {
		    	foreach ($request->options as $option) {
		    		if (!empty($option)) {
		    			Option::create([
			    			'name'=>$option,
			    			'option_group_id'=>$resource->id
			    		]);	
		    		}
		    	}
	    	}

	    	DB::commit();

	    	$msg = 'New Group Added Successfully.<a href="' . route('admin.option_groups.index') . '">View Groups Lists.</a>';
        	return response()->json($msg);
    	} catch (Exception $e) {
    		DB::rollBack();
    		return response()->json(array('errors' => [$e->getMessage()]));
    	}
    }

    public function destroy($id){

    	DB::beginTransaction();

    	try {

    		OptionGroup::where('id',$id)->delete();

    		option::where('option_group_id',$id)->delete();
    		
    		DB::commit();

    		$msg = ['success'=>'Group Deleted Successfully.'];

    	} catch (Exception $e) {

    		DB::rollBack();

    		$msg = ['errors'=>$e->getMessage()] ;

    	}

    	return redirect()->route('admin.option_groups.index')->with($msg);
    }

}
