<?php

namespace App\Providers;

use App;
use Session;
use App\Models\User;
use App\Models\Category;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\ServiceProvider;
use Illuminate\Pagination\LengthAwarePaginator;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {

        $admin_lang = DB::table('admin_languages')->where('is_default','=',1)->first();
        App::setlocale($admin_lang->name);
        User::chekValidation();

        view()->composer('*',function($settings){

            $settings->with('gs', cache()->remember('generalsettings', now()->addDay(), function () {
                return DB::table('generalsettings')->first();
            }));

            $settings->with('seo', cache()->remember('seotools', now()->addDay(), function () {
                return DB::table('seotools')->first();
            }));
            
            $settings->with('socialsetting', cache()->remember('socialsettings', now()->addDay(), function () {
                return DB::table('socialsettings')->first();
            }));

            $settings->with('categories', cache()->remember('categories', now()->addDay(), function () {
                return Category::with('subs')->where('status','=',1)->get();
            }));

            if (Session::has('language')){
                $data = cache()->remember('session_language', now()->addDay(), function () {
                    return DB::table('languages')->find(Session::get('language'));
                });
                $data_results = file_get_contents(public_path().'/assets/languages/'.$data->file);
                $lang = json_decode($data_results);
                $settings->with('langg', $lang);
            }
            else{
                $data = cache()->remember('default_language', now()->addDay(), function () {
                    return DB::table('languages')->where('is_default','=',1)->first();
                });
                

                // $data_results = file_get_contents(public_path().'assets/languages/'.$data->file);
                $data_results = '{
    "rtl": "1",
    "lang16": "Track Order",
    "lang11": "My Account",
    "lang221": "User Panel",
    "lang222": "Vendor Panel",
    "lang223": "Logout",
    "lang12": "Sign in",
    "lang13": "Join",
    "lang220": "Sell",
    "lang1": "All Categories",
    "lang2": "Search For Product",
    "lang3": "Cart",
    "lang4": "Item(s)",
    "lang5": "View Cart",
    "lang6": "Total",
    "lang7": "Checkout",
    "lang8": "Cart is empty.",
    "lang9": "Wish",
    "lang10": "Compare",
    "lang14": "Categories",
    "lang15": "See All Categories",
    "lang17": "Home",
    "lang18": "Blog",
    "lang19": "Faq",
    "lang20": "Contact Us",
    "lang25": "Shop Now",
    "lang26": "Featured",
    "lang27": "Best Seller",
    "lang244": "Flash Deal",
    "lang28": "Top Rated",
    "lang29": "Big Save",
    "lang30": "Hot",
    "lang31": "New",
    "lang32": "Trending",
    "lang33": "Sale",
    "lang34": "Read More",
    "lang236": "Brands",
    "lang35": "Tag",
    "lang36": "Search",
    "lang37": "Archive",
    "lang38": "Read More",
    "lang39": "Blog Details",
    "lang40": "View(s)",
    "lang41": "Source",
    "lang46": "Search",
    "lang42": "Categories",
    "lang43": "Recent Post",
    "lang44": "Archives",
    "lang45": "Tags",
    "lang47": "Name",
    "lang48": "Phone Number",
    "lang49": "Email Address",
    "lang50": "Your Message",
    "lang51": "Enter Code",
    "lang52": "Send Message",
    "lang53": "Find Us Here",
    "lang54": "Add To Wishlist",
    "lang55": "Quick View",
    "lang56": "Add To Cart",
    "lang57": "Compare",
    "lang251": "Buy Now",
    "lang58": "Search",
    "lang59": "Tag",
    "lang60": "No Product Found.",
    "lang61": "Filter Results By",
    "lang62": "To",
    "lang63": "Popular Tags",
    "lang64": "Sort By",
    "lang65": "Latest Product",
    "lang66": "Oldest Product",
    "lang67": "Lowest Price",
    "lang68": "Highest Price",
    "lang69": "Compare",
    "lang70": "Product Compare",
    "lang71": "Product Name",
    "lang72": "Price",
    "lang73": "Rating",
    "lang74": "Description",
    "lang75": "Add To Cart",
    "lang76": "Remove",
    "lang77": "Product SKU",
    "lang78": "Out Of Stock",
    "lang79": "In Stock",
    "lang80": "Review(s)",
    "lang224": "Add To Favorite Seller",
    "lang225": "Favorite",
    "lang81": "Contact Seller",
    "lang82": "Platform",
    "lang83": "Region",
    "lang84": "License Type",
    "lang85": "Product Condition",
    "lang219": "Watch Video",
    "lang86": "Estimated Shipping Time",
    "lang87": "Price",
    "lang88": "Size",
    "lang89": "Color",
    "lang90": "Add to Cart",
    "lang91": "SHARE",
    "lang92": "DESCRIPTION",
    "lang93": "BUY & RETURN POLICY",
    "lang94": "Reviews",
    "lang95": "Comment",
    "lang96": "Ratings & Reviews",
    "lang97": "No Review Found.",
    "lang98": "Review",
    "lang99": "Your Review",
    "lang100": "SUBMIT",
    "lang101": "Login",
    "lang102": "To Review",
    "lang103": "To Comment",
    "lang104": "Write Comment",
    "lang105": "Write Your Comments Here...",
    "lang106": "Post Comment",
    "lang107": "Reply",
    "lang108": "View",
    "lang109": "Reply",
    "lang110": "Replies",
    "lang111": "Edit",
    "lang112": "Delete",
    "lang113": "Edit Your Comment",
    "lang114": "Submit",
    "lang115": "Cancel",
    "lang116": "Edit Your Reply",
    "lang117": "Write your reply",
    "lang118": "Send Message",
    "lang119": "Subject *",
    "lang120": "Your Message",
    "lang199": "Product Quick View",
    "lang216": "Related Products",
    "lang245": "Seller`s Products",
    "lang246": "Sold By",
    "lang247": "No Vendor Found",
    "lang248": "Total Item",
    "lang249": "Visit Store",
    "lang770": "Wholesell",
    "lang768": "Quantity",
    "lang769": "Discount",
    "lang771": "Off",
    "lang776": "Report This Item",
    "lang777": "REPORT PRODUCT",
    "lang778": "Please give the following details",
    "lang779": "Enter Report Title",
    "lang780": "Enter Report Note",
    "lang783": "Verified",
    "lang121": "Cart",
    "lang122": "Product Name",
    "lang123": "Size & Color",
    "lang124": "Quantity",
    "lang125": "Unit Price",
    "lang126": "Sub Total",
    "lang127": "PRICE DETAILS",
    "lang128": "Total MRP",
    "lang129": "Discount",
    "lang130": "Tax",
    "lang131": "Total",
    "lang132": "Have a promotion code?",
    "lang133": "Coupon Code",
    "lang134": "Apply",
    "lang135": "Place Order",
    "lang136": "Checkout",
    "lang137": "Product Name",
    "lang138": "Size",
    "lang139": "Color",
    "lang140": "Quantity",
    "lang141": "Unit Price",
    "lang142": "Sub Total",
    "lang143": "Shipping Cost",
    "lang144": "Tax",
    "lang145": "Discount",
    "lang146": "Total",
    "lang147": "Billing Details",
    "lang148": "Shipping Details",
    "lang149": "Ship To Address",
    "lang150": "Pick Up",
    "lang151": "Pickup Location",
    "lang152": "Full Name",
    "lang153": "Phone Number",
    "lang154": "Email",
    "lang155": "Address",
    "lang156": "Country",
    "lang157": "Select Country",
    "lang158": "City",
    "lang159": "Postal Code",
    "lang160": "Ship to a Different Address?",
    "lang161": "Payment Information",
    "lang217": "Order Note",
    "lang218": "Optional",
    "lang162": "Order Now",
    "lang163": "Card Number",
    "lang164": "Cvv",
    "lang165": "Month",
    "lang166": "Year",
    "lang167": "Transaction ID#",
    "lang743": "Address",
    "lang744": "Orders",
    "lang745": "Payment",
    "lang746": "Personal Information",
    "lang747": "Enter Your Name",
    "lang748": "Enter Your Email",
    "lang749": "Create an account ?",
    "lang750": "Enter Your Password",
    "lang751": "Confirm Your Password",
    "lang752": "Shipping Details",
    "lang753": "Continue",
    "lang754": "Price",
    "lang755": "Quantity",
    "lang756": "Total Price",
    "lang757": "Back",
    "lang758": "Shipping Info",
    "lang759": "Payment Info",
    "lang760": "PayPal Express",
    "lang761": "Credit Card",
    "lang762": "Cash On Delivery",
    "lang763": "Instamojo",
    "paytm": "Paytm",
    "razorpay": "Razorpay",
    "lang764": "Paystack",
    "lang802": "Mollie Payment",
    "lang765": "Shipping Method",
    "lang766": "Packaging",
    "lang767": "Final Price",
    "lang781": "Card number not valid",
    "lang782": "CVC number not valid",
    "lang168": "Wishlists",
    "lang169": "Success",
    "lang170": "Get Back To Our Homepage",
    "lang171": "Login & Register",
    "lang172": "LOGIN NOW",
    "lang173": "Type Email Address",
    "lang174": "Type Password",
    "lang175": "Remember Password",
    "lang176": "Forgot Password?",
    "lang177": "Authenticating...",
    "lang178": "Login",
    "lang234": "Vendor Login",
    "lang179": "Or",
    "lang180": "Sign In with social media",
    "lang181": "Signup Now",
    "lang182": "Full Name",
    "lang183": "Email Address",
    "lang184": "Phone Number",
    "lang185": "Address",
    "lang186": "Password",
    "lang187": "Confirm Password",
    "lang188": "Processing...",
    "lang189": "Register",
    "lang235": "Vendor Registration",
    "lang197": "Login",
    "lang198": "Register",
    "lang190": "Forgot Password",
    "lang191": "Forgot Password",
    "lang192": "Please Write your Email",
    "lang193": "Email Address",
    "lang194": "Login Now",
    "lang195": "Checking...",
    "lang196": "SUBMIT",
    "lang226": "Store Name",
    "lang227": "Service Center",
    "lang228": "Contact Now",
    "lang229": "Follow Us",
    "lang238": "Shop Name",
    "lang239": "Owner Name",
    "lang240": "Shop Number",
    "lang241": "Shop Address",
    "lang242": "Registration Number",
    "lang243": "Message",
    "lang21": "Footer Links",
    "lang22": "Home",
    "lang23": "Contact Us",
    "lang24": "Recent Post",
    "add_cart": "Successfully Added To Cart",
    "already_cart": "Already Added To Cart",
    "out_stock": "Out Of Stock",
    "add_wish": "Successfully Added To Wishlist",
    "already_wish": "Already Added To Wishlist",
    "wish_remove": "Successfully Removed From The Wishlist",
    "add_compare": "Successfully Added To Compare",
    "already_compare": "Already Added To Compare",
    "compare_remove": "Successfully Removed From The Compare",
    "color_change": "Successfully Changed The Color",
    "coupon_found": "Coupon Found",
    "no_coupon": "No Coupon Found",
    "already_coupon": "Coupon Already Applied",
    "email_not_found": "Email Not Found",
    "something_wrong": "Oops Something Goes Wrong !!",
    "message_sent": "Message Sent !!",
    "order_title": "THANK YOU FOR YOUR PURCHASE.",
    "order_text": "We`ll email you an order confirmation with details and tracking info.",
    "subscribe_success": "You have subscribed successfully.",
    "subscribe_error": "This email has already been taken.",
    "lang741": "Enter Your Email Address",
    "lang742": "SUBSCRIBE",
    "lang427": "404",
    "lang428": "Oops! You`re lost...",
    "lang429": "The page you are looking for might have been moved, renamed, or might never existed.",
    "lang430": "Back Home",
    "lang200": "Dashboard",
    "lang230": "Vendor Panel",
    "lang201": "Purchased Items",
    "lang202": "Affiliate Code",
    "lang203": "Withdraw",
    "lang231": "Favorite Sellers",
    "lang232": "Messages",
    "lang204": "Tickets",
    "lang250": "Disputes",
    "lang205": "Edit Profile",
    "lang206": "Reset Password",
    "lang207": "Logout",
    "lang233": "Start Selling",
    "lang237": "Pricing Plans",
    "lang208": "Account Information",
    "lang209": "Email",
    "lang210": "Phone",
    "lang211": "Fax",
    "lang212": "City",
    "lang213": "Zip",
    "lang214": "Address",
    "lang215": "Affiliate Bonus",
    "lang277": "Purchased Items",
    "lang278": "#Order",
    "lang279": "Date",
    "lang280": "Order Total",
    "lang281": "Order Status",
    "lang282": "View",
    "lang283": "VIEW ORDER",
    "lang284": "My Order Details",
    "lang285": "Order#",
    "lang286": "print order",
    "lang301": "Order Date",
    "lang287": "Billing Address",
    "lang288": "Name:",
    "lang289": "Email:",
    "lang290": "Phone:",
    "lang291": "Address:",
    "lang292": "Payment Information",
    "lang293": "Paid Amount:",
    "lang294": "Payment Method:",
    "lang295": "Charge ID:",
    "lang296": "Transaction ID:",
    "lang297": "Edit Transaction ID",
    "lang298": "Cancel",
    "lang299": "Enter Transaction ID & Press Enter",
    "lang300": "Submit",
    "lang302": "Shipping Address",
    "lang303": "PickUp Location",
    "lang304": "Address:",
    "lang305": "Shipping Method",
    "lang306": "Ship To Address",
    "lang307": "Pick Up",
    "lang308": "Ordered Products:",
    "lang309": "ID#",
    "lang310": "Name",
    "lang311": "Quantity",
    "lang312": "Size",
    "lang313": "Color",
    "lang314": "Price",
    "lang315": "Total",
    "lang316": "Download",
    "lang317": "View License",
    "lang318": "Back",
    "lang319": "License Key",
    "lang320": "The Licenes Key is :",
    "lang321": "Close",
    "lang322": "Affiliate Informations",
    "lang323": "Your Affilate Link *",
    "lang324": "This is your affilate link just copy the link and paste anywhere you want.",
    "lang325": "Affiliate Banner *",
    "lang326": "This is your affilate banner Preview.",
    "lang327": "Affiliate Banner HTML Code *",
    "lang328": "This is your affilate banner html code just copy the code and paste anywhere you want.",
    "lang329": "My Withdraws",
    "lang330": "Withdraw Now",
    "lang331": "Withdraw Date",
    "lang332": "Method",
    "lang333": "Account",
    "lang334": "Amount",
    "lang335": "Status",
    "lang336": "Withdraw Now",
    "lang337": "Back",
    "lang338": "Withdraw Method",
    "lang339": "Select Withdraw Method",
    "lang340": "Paypal",
    "lang341": "Skrill",
    "lang342": "Payoneer",
    "lang343": "Bank",
    "lang344": "Withdraw Amount",
    "lang345": "Enter Account Email",
    "lang346": "Enter IBAN\/Account No",
    "lang347": "Enter Account Name",
    "lang348": "Enter Address",
    "lang349": "Enter Swift Code",
    "lang350": "Additional Reference(Optional)",
    "lang351": "Withdraw Fee",
    "lang352": "and",
    "lang353": "will deduct from your account.",
    "lang354": "Withdraw",
    "lang355": "Current Balance",
    "lang772": "Order Tracking",
    "lang773": "Get Tracking Code",
    "lang774": "View Tracking",
    "lang775": "No Order Found",
    "lang252": "Favorite Sellers",
    "lang253": "Shop Name",
    "lang254": "Owner Name",
    "lang255": "Address",
    "lang256": "Actions",
    "lang257": "Confirm Delete",
    "lang258": "You are about to delete this Seller.",
    "lang259": "Do you want to proceed?",
    "lang260": "Cancel",
    "lang261": "Delete",
    "lang356": "Messages",
    "lang357": "Compose Message",
    "lang358": "Name",
    "lang359": "Message",
    "lang360": "Sent",
    "lang361": "Action",
    "lang362": "Send Message",
    "lang363": "Email",
    "lang364": "Subject",
    "lang365": "Your Message",
    "lang366": "Send Message",
    "lang367": "Confirm Delete",
    "lang368": "You are about to delete this Conversation.",
    "lang369": "Do you want to proceed?",
    "lang370": "Cancel",
    "lang371": "Delete",
    "lang372": "Conversation with",
    "lang373": "Back",
    "lang374": "Message",
    "lang375": "Add Reply",
    "lang376": "Tickets",
    "lang377": "Add Ticket",
    "lang378": "Disputes",
    "lang379": "Add Dispute",
    "lang380": "Subject",
    "lang381": "Message",
    "lang382": "Time",
    "lang383": "Action",
    "lang384": "Add Ticket",
    "lang385": "Add Dispute",
    "lang386": "Order Number",
    "lang387": "Subject",
    "lang388": "Your Message",
    "lang389": "Send",
    "lang390": "Confirm Delete",
    "lang391": "You are about to delete this Ticket.",
    "lang392": "You are about to delete this Dispute.",
    "lang393": "Do you want to proceed?",
    "lang394": "Cancel",
    "lang395": "Delete",
    "lang396": "Order Number:",
    "lang397": "Subject:",
    "lang398": "Back",
    "lang399": "Admin",
    "lang400": "Message",
    "lang401": "Add Reply",
    "lang262": "Edit Profile",
    "lang263": "Upload",
    "lang264": "User Name",
    "lang265": "Email Address",
    "lang266": "Phone Number",
    "lang267": "Fax",
    "lang268": "City",
    "lang269": "Zip",
    "lang270": "Address",
    "lang271": "Save",
    "lang272": "Reset Password",
    "lang273": "Current Password",
    "lang274": "New Password",
    "lang275": "Re-Type New Password",
    "lang276": "Submit",
    "lang402": "Free",
    "lang403": "Day(s)",
    "lang404": "Current Plan",
    "lang405": "Expired on:",
    "lang406": "Ends on:",
    "lang407": "Renew",
    "lang408": "Get Started",
    "lang409": "Package Details",
    "lang410": "Back",
    "lang411": "Plan:",
    "lang412": "Price:",
    "lang413": "Durations:",
    "lang414": "Product(s) Allowed:",
    "lang415": "Note:",
    "lang416": "Your Previous Plan will be deactivated!",
    "lang417": "(Optional)",
    "lang418": "Select Payment Method",
    "lang419": "Select an option",
    "lang420": "Paypal",
    "lang421": "Stripe",
    "lang422": "Card",
    "lang423": "Cvv",
    "lang424": "Month",
    "lang425": "Year",
    "lang426": "Submit",
    "lang517": "(In Any Language)",
    "lang518": "ADD NEW",
    "lang519": "EDIT",
    "lang431": "Welcome!",
    "lang432": "Visit Store",
    "lang433": "User Panel",
    "lang434": "Edit Profile",
    "lang435": "Logout",
    "lang436": "New Order(s).",
    "lang437": "Clear All",
    "lang438": "You Have a new order.",
    "lang439": "No New Notifications.",
    "lang440": "Visit Store",
    "lang441": "Dashbord",
    "lang442": "Orders",
    "lang443": "All Orders",
    "lang444": "Products",
    "lang445": "Add New Product",
    "lang446": "All Products",
    "lang785": "Product Catalogs",
    "lang447": "Affiliate Products",
    "lang448": "Add Affiliate Product",
    "lang449": "All Affiliate Products",
    "lang450": "Bulk Product Upload",
    "lang451": "Withdraws",
    "lang452": "Settings",
    "lang453": "Services",
    "lang454": "Banner",
    "lang455": "Shipping Cost",
    "lang456": "Social Links",
    "lang784": "Verify Account",
    "lang457": "Shop Name",
    "lang458": "Owner Name",
    "lang459": "Shop Number",
    "lang460": "Shop Address",
    "lang461": "Registration Number",
    "lang462": "(Optional)",
    "lang463": "Shop Details",
    "lang464": "Save",
    "lang786": "Vendor Verification",
    "lang787": "Details",
    "lang788": "Enter Verification Details",
    "lang789": "Attachment",
    "lang792": "(Maximum Size is: 10MB)",
    "lang790": "Add More Attachment",
    "lang791": "Submit",
    "lang803": "Verify Now",
    "lang804": "Your Documents Submitted Successfully.",
    "lang465": "Orders Pending!",
    "lang466": "Orders Procsessing!",
    "lang467": "Orders Completed!",
    "lang468": "Total Products!",
    "lang469": "Total Item Sold!",
    "lang470": "Total Earnings!",
    "lang471": "View All",
    "lang534": "Order Number",
    "lang535": "Total Qty",
    "lang536": "Total Cost",
    "lang537": "Payment Method",
    "lang538": "Actions",
    "lang539": "Details",
    "lang540": "Pending",
    "lang541": "Processing",
    "lang542": "Completed",
    "lang543": "Declined",
    "lang544": "Update Status",
    "lang545": "You are about to update the Order`s Status.",
    "lang546": "Do you want to proceed?",
    "lang547": "Cancel",
    "lang548": "Proceed",
    "lang549": "Order Details",
    "lang795": "Payment Method",
    "lang796": "Charge ID",
    "lang797": "Transaction ID",
    "lang798": "Payment Status",
    "lang799": "Unpaid",
    "lang800": "Paid",
    "lang801": "Order Note",
    "lang550": "Back",
    "lang551": "Order ID",
    "lang552": "Total Product",
    "lang553": "Total Cost",
    "lang554": "Ordered Date",
    "lang555": "View Invoice",
    "lang556": "Billing Details",
    "lang557": "Customer Name",
    "lang558": "Email",
    "lang559": "Phone",
    "lang560": "Address",
    "lang561": "Country",
    "lang562": "City",
    "lang563": "Postal Code",
    "lang564": "Shipping Details",
    "lang565": "Pickup Location",
    "lang566": "Products Ordered",
    "lang567": "Product ID#",
    "lang568": "Shop Name",
    "lang569": "Status",
    "lang570": "Product Title",
    "lang571": "Quantity",
    "lang572": "Size",
    "lang573": "Color",
    "lang574": "Total Price",
    "lang575": "Vendor Removed",
    "lang576": "Send Email",
    "lang577": "License Key",
    "lang578": "The Licenes Key is",
    "lang579": "Enter New License Key",
    "lang580": "Close",
    "lang584": "Cancel",
    "lang585": "Save License",
    "lang583": "Email Address",
    "lang581": "Subject",
    "lang582": "Your Message",
    "lang586": "Order Invoice",
    "lang587": "Billing Address",
    "lang588": "Invoice Number",
    "lang589": "Order Date",
    "lang590": "Order ID",
    "lang591": "Product",
    "lang592": "Size",
    "lang593": "Color",
    "lang594": "Price",
    "lang595": "Qty",
    "lang596": "Packaging Cost",
    "lang597": "Subtotal",
    "lang598": "Shipping Cost",
    "lang599": "TAX",
    "lang600": "Total",
    "lang601": "Order Details",
    "lang602": "Shipping Method",
    "lang603": "Pick Up",
    "lang604": "Ship To Address",
    "lang605": "Payment Method",
    "lang606": "Shipping Address",
    "lang607": "Print Invoice",
    "lang608": "Name",
    "lang793": "Product Sku",
    "lang794": "Enter Product Sku",
    "lang609": "Type",
    "lang610": "Price",
    "lang611": "Status",
    "lang612": "Actions",
    "lang713": "Activated",
    "lang714": "Deactivated",
    "lang715": "Edit",
    "lang716": "View Gallery",
    "lang613": "Close",
    "lang614": "Confirm Delete",
    "lang615": "You are about to delete this Product.",
    "lang616": "Do you want to proceed?",
    "lang617": "Cancel",
    "lang618": "Delete",
    "lang619": "Image Gallery",
    "lang620": "Upload File",
    "lang621": "Done",
    "lang622": "You can upload multiple Images.",
    "lang623": "Add New Product",
    "lang624": "No Images Found.",
    "lang625": "Product Types",
    "lang626": "Physical",
    "lang627": "Digital",
    "lang628": "License",
    "lang629": "Physical Product",
    "lang630": "Digital Product",
    "lang631": "License Product",
    "lang632": "Product Name",
    "lang633": "Allow Product Condition",
    "lang634": "Product Condition",
    "lang635": "New",
    "lang636": "Used",
    "lang637": "Category",
    "lang691": "Select Category",
    "lang638": "Sub Category",
    "lang639": "Select Sub Category",
    "lang640": "Child Category",
    "lang641": "Select Child Category",
    "lang642": "Feature Image",
    "lang643": "Upload Image Here",
    "lang644": "Product Gallery Images",
    "lang645": "Set Gallery",
    "lang646": "Allow Estimated Shipping Time",
    "lang647": "Product Estimated Shipping Time",
    "lang648": "Allow Product Sizes",
    "lang649": "Size Name",
    "lang650": "(eg. S,M,L,XL,XXL,3XL,4XL)",
    "lang651": "Size Qty",
    "lang652": "(Number of quantity of this size)",
    "lang653": "Size Price",
    "lang654": "(This price will be added with base price)",
    "lang655": "Add More Size",
    "lang656": "Allow Product Colors",
    "lang657": "Product Colors",
    "lang658": "(Choose Your Favorite Colors)",
    "lang659": "Add More Color",
    "lang660": "Allow Product Whole Sell",
    "lang661": "Enter Quantity",
    "lang662": "Enter Discount Percentage",
    "lang663": "Add More Field",
    "lang664": "Product Current Price",
    "lang665": "In",
    "lang666": "e.g 20",
    "lang667": "Product Previous Price",
    "lang668": "(Optional)",
    "lang669": "Product Stock",
    "lang670": "(Leave Empty will Show Always Available)",
    "lang671": "Allow Product Measurement",
    "lang672": "Product Measurement",
    "lang673": "None",
    "lang674": "Gram",
    "lang675": "Kilogram",
    "lang676": "Litre",
    "lang677": "Pound",
    "lang678": "Custom",
    "lang679": "Enter Unit",
    "lang680": "Product Description",
    "lang681": "Product Buy\/Return Policy",
    "lang682": "Youtube Video URL",
    "lang683": "Allow Product SEO",
    "lang684": "Meta Tags",
    "lang685": "Meta Description",
    "lang686": "Feature Tags",
    "lang687": "Enter Your Keyword",
    "lang688": "Add More Field",
    "lang689": "Tags",
    "lang690": "Create Product",
    "lang692": "Select Upload Type",
    "lang693": "Upload By File",
    "lang694": "Upload By Link",
    "lang695": "Select File",
    "lang696": "Link",
    "lang697": "Product License",
    "lang698": "License Key",
    "lang699": "License Quantity",
    "lang700": "Add More Field",
    "lang701": "Product Platform",
    "lang702": "Product Region",
    "lang703": "License Type",
    "lang704": "Edit Product",
    "lang705": "Edit",
    "lang706": "Save",
    "lang707": "Product Affiliate Link",
    "lang708": "(External Link)",
    "lang709": "Feature Image Source",
    "lang710": "File",
    "lang711": "Link",
    "lang712": "Feature Image Link",
    "lang531": "Download Sample CSV",
    "lang532": "Upload a File",
    "lang533": "Start Import",
    "lang472": "My Withdraws",
    "lang473": "Withdraw Now",
    "lang474": "Withdraw Date",
    "lang475": "Method",
    "lang476": "Account",
    "lang477": "Amount",
    "lang478": "Status",
    "lang479": "Withdraw Now",
    "lang480": "Back",
    "lang481": "Withdraw Method",
    "lang482": "Select Withdraw Method",
    "lang483": "Paypal",
    "lang484": "Skrill",
    "lang485": "Payoneer",
    "lang486": "Bank",
    "lang487": "Withdraw Amount",
    "lang488": "Enter Account Email",
    "lang489": "Enter IBAN\/Account No",
    "lang490": "Enter Account Name",
    "lang491": "Enter Address",
    "lang492": "Enter Swift Code",
    "lang493": "Additional Reference(Optional)",
    "lang494": "Withdraw Fee",
    "lang495": "and",
    "lang496": "will deduct from your account.",
    "lang497": "Withdraw",
    "lang498": "Current Balance",
    "lang499": "SERVICE",
    "lang500": "Featured Image",
    "lang501": "Title",
    "lang502": "Actions",
    "lang717": "Edit",
    "lang503": "Close",
    "lang504": "Confirm Delete",
    "lang505": "You are about to delete this Service.",
    "lang506": "Do you want to proceed?",
    "lang507": "Cancel",
    "lang508": "Delete",
    "lang509": "Add New Service",
    "lang510": "Title",
    "lang511": "Current Featured Image",
    "lang512": "Upload Image",
    "lang513": "Prefered Size: (600x600) or Square Sized Image",
    "lang514": "Description",
    "lang515": "Create Service",
    "lang516": "Save",
    "lang718": "SHIPPING METHOD",
    "lang719": "Shipping Methods",
    "lang720": "PACKAGING",
    "lang721": "Packagings",
    "lang722": "Title",
    "lang723": "Price",
    "lang724": "Actions",
    "lang725": "Edit",
    "lang726": "Close",
    "lang734": "Confirm Delete",
    "lang727": "You are about to delete this Shipping Method.",
    "lang728": "You are about to delete this Packaging.",
    "lang729": "Do you want to proceed?",
    "lang730": "Cancel",
    "lang731": "Delete",
    "lang732": "Add New Shipping Method",
    "lang733": "Add New Packaging",
    "lang735": "Title",
    "lang736": "Subtitle",
    "lang737": "Duration",
    "lang738": "Price",
    "lang739": "Create",
    "lang740": "Save",
    "lang520": "Current Banner",
    "lang521": "Prefered Size: (1920x220) or Square Sized Image",
    "lang522": "Upload Banner",
    "lang523": "Save",
    "lang524": "Shipping Cost",
    "lang525": "Save",
    "lang526": "Facebook",
    "lang527": "Google Plus",
    "lang528": "Twitter",
    "lang529": "Linkedin",
    "lang530": "Save"
}';
                // dd(public_path().'/assets/languages/'.$data->file);
                $lang = json_decode($data_results);
                
                // dd($lang);

                $settings->with('langg', $lang);
            }

            if (!Session::has('popup'))
            {
                $settings->with('visited', 1);
            }

            Session::put('popup' , 1);

        });
    }

    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {

        Collection::macro('paginate', function($perPage, $total = null, $page = null, $pageName = 'page') {
            $page = $page ?: LengthAwarePaginator::resolveCurrentPage($pageName);
            return new LengthAwarePaginator(
                $this->forPage($page, $perPage),
                $total ?: $this->count(),
                $perPage,
                $page,
                [
                    'path' => LengthAwarePaginator::resolveCurrentPath(),
                    'pageName' => $pageName,
                ]
            );
        });

    }
}
